"use strict";
var ControlLoopService_1;
Object.defineProperty(exports, "__esModule", { value: true });
exports.ControlLoopService = void 0;
const tslib_1 = require("tslib");
const common_1 = require("@nestjs/common");
const schedule_1 = require("@nestjs/schedule");
const nestjs_logger_1 = require("@globetracker/nestjs-logger");
const constants_1 = require("../constants");
const nestjs_async_module_1 = require("@jbiskur/nestjs-async-module");
const event_emitter_1 = require("@nestjs/event-emitter");
const nestjs_kubernetes_client_1 = require("@globetracker/nestjs-kubernetes-client");
let ControlLoopService = ControlLoopService_1 = class ControlLoopService {
    constructor(logger, options, kubernetesClient, eventEmitter, scheduleRegistry) {
        this.logger = logger;
        this.options = options;
        this.kubernetesClient = kubernetesClient;
        this.eventEmitter = eventEmitter;
        this.scheduleRegistry = scheduleRegistry;
    }
    runControlLoop() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const resources = this.options.get().observedResources;
            yield Promise.all(resources.map((resource) => tslib_1.__awaiter(this, void 0, void 0, function* () {
                this.logger.debug(`Running control loop for resource ${resource.plural}`, resource);
                const items = yield this.listResource(resource);
            })));
        });
    }
    listResource(resource) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            let items;
            switch (resource.namespaced) {
                case true:
                    break;
                case false:
                    break;
            }
            try {
                items = yield this.kubernetesClient
                    .getCustomApi()
                    .listNamespacedCustomObject(resource.group, resource.version, resource.namespace, resource.plural);
                console.log(items);
            }
            catch (e) {
                this.logger.error(`Failed to list resources`, e);
            }
            return items;
        });
    }
    onApplicationBootstrap() {
        var _a, _b;
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            if (!this.scheduleRegistry) {
                this.logger.warn("Scheduler disabled for this service");
                return;
            }
            this.logger.info(`Starting scheduler to run at interval (${(_a = this.options.get().controlLoopInterval) !== null && _a !== void 0 ? _a : constants_1.DEFAULT_CONTROL_LOOP_INTERVAL})`);
            const interval = setInterval(this.runControlLoop.bind(this), (_b = this.options.get().controlLoopInterval) !== null && _b !== void 0 ? _b : constants_1.DEFAULT_CONTROL_LOOP_INTERVAL);
            this.scheduleRegistry.addInterval("runControlLoop", interval);
        });
    }
};
ControlLoopService = ControlLoopService_1 = tslib_1.__decorate([
    common_1.Injectable(),
    tslib_1.__param(0, nestjs_logger_1.InjectGTLogger(ControlLoopService_1.name)),
    tslib_1.__param(4, common_1.Optional()),
    tslib_1.__metadata("design:paramtypes", [nestjs_logger_1.GTLoggerService,
        nestjs_async_module_1.ModuleOptions,
        nestjs_kubernetes_client_1.KubernetesClientService,
        event_emitter_1.EventEmitter2,
        schedule_1.SchedulerRegistry])
], ControlLoopService);
exports.ControlLoopService = ControlLoopService;
//# sourceMappingURL=control-loop.service.js.map